"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _github = _interopRequireDefault(require("../../services/github"));

var _Input = _interopRequireDefault(require("../Input"));

var _Select = _interopRequireDefault(require("../Select"));

var _Button = _interopRequireDefault(require("../Button"));

var _styles = require("./styles");

var _core = require("@emotion/core");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Configuration = ({
  insomniaContext
}) => {
  const [provider, setProvider] = (0, _react.useState)('github');
  const [apiKey, setApiKey] = (0, _react.useState)('');
  const [gistKey, setGistKey] = (0, _react.useState)('');
  const [ignoredWorkspaces, setIgnoredWorkspaces] = (0, _react.useState)('');
  const [gistOptions, setGistsOptions] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    async function loadGists() {
      const CREATE_NEW_OPTION = {
        label: 'Create new...',
        value: null
      };

      try {
        if (!apiKey) throw new Error('API Key not provided.');
        const gitHubService = new _github.default(apiKey);
        const gists = await gitHubService.getGists();
        const options = gists.map(gist => ({
          label: `${gist.description} (ID: ${gist.id})`,
          value: gist.id
        }));
        setGistsOptions([CREATE_NEW_OPTION, ...options]);
      } catch (error) {
        setGistsOptions([CREATE_NEW_OPTION]);
      }
    }

    loadGists();
  }, [apiKey]);
  (0, _react.useEffect)(() => {
    async function load() {
      const newApiKey = await insomniaContext.store.getItem('gist-sync:api-key');
      const newGistKey = await insomniaContext.store.getItem('gist-sync:gist-key');
      const newIgnoredWorkspaces = await insomniaContext.store.getItem('gist-sync:ignored-workspaces');
      setApiKey(newApiKey);
      setGistKey(newGistKey);
      setIgnoredWorkspaces(newIgnoredWorkspaces);
    }

    load();
  }, []);
  const handleConfirm = (0, _react.useCallback)(() => {
    async function execute() {
      await insomniaContext.store.setItem('gist-sync:api-key', apiKey ?? '');
      await insomniaContext.store.setItem('gist-sync:gist-key', gistKey ?? '');
      await insomniaContext.store.setItem('gist-sync:ignored-workspaces', ignoredWorkspaces ?? '');
    }

    execute();
  }, [apiKey, gistKey, ignoredWorkspaces]);
  return (0, _core.jsx)("div", {
    css: _styles.containerStyle
  }, (0, _core.jsx)(_Select.default, {
    label: "Provider",
    options: [{
      label: 'GitHub',
      value: 'github'
    }],
    value: "provider",
    onChange: event => setProvider(event.target.value)
  }), (0, _core.jsx)(_Input.default, {
    label: "Gist API Key",
    value: apiKey,
    onChange: event => setApiKey(event.target.value)
  }), (0, _core.jsx)(_Select.default, {
    label: "Gist",
    options: gistOptions,
    value: gistKey,
    onChange: event => setGistKey(event.target.value)
  }), (0, _core.jsx)(_Input.default, {
    label: "Ignore Workspaces",
    value: ignoredWorkspaces,
    placeholder: "add comma-separated workspace names",
    onChange: event => setIgnoredWorkspaces(event.target.value)
  }), (0, _core.jsx)("div", {
    css: _styles.actionsContainerStyle
  }, (0, _core.jsx)(_Button.default, {
    label: "Cancel",
    closeModal: true
  }), (0, _core.jsx)(_Button.default, {
    label: "Confirm",
    onClick: handleConfirm,
    closeModal: true
  })));
};

var _default = Configuration;
exports.default = _default;